#!/usr/bin/env python

from distutils.core import setup
from setuptools import find_packages

setup(
    name='django-ucamprojectlight',
    description='A Django module to use the template system of the University of Cambridge: Project light',
    long_description=open('README.rst').read(),
    url='https://github.com/uisautomation/django-ucamprojectlight.git',
    # When changing this version number, remember to update
    # django-ucamprojectlight.spec and debian/changelog.
    version='1.2',
    license='MIT',
    author='University of Cambridge',
    author_email='information-systems@ucs.cam.ac.uk',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
)



from django import template

register = template.Library()

@register.filter
def elliptic_range(num_pages, current):
    """
    Produce a list of numbers from 1 to num_pages and including current.
    Long runs of successive numbers will be replaced by "...".
    """
    def gap(start, stop):
        if stop - start < 3:
            return range(start, stop)
        return ["..."]
    ret = []
    if current != 1:
        ret += [1]
        ret += gap(2, current)
    ret += [current]
    if current != num_pages:
        ret += gap(current + 1, num_pages)
        ret += [num_pages]
    return ret
